==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/core/lumina-open/i18n/lumina-open_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Abrir Com..</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Disponíveis</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Localização do Binário:</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Definir essa aplicação como padrão</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(Link de E-mail)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimédia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Educação</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Jogo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Ciência</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Utilitários</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="211"/>
        <source>[default] </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="278"/>
        <source>Find Application Binary</source>
        <translation>Encontrar binário da aplicação</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>File Error</source>
        <translation>Erro no Arquivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="191"/>
        <location filename="../main.cpp" line="197"/>
        <source>Audio Volume %1%</source>
        <translation>Volume do Som %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="205"/>
        <location filename="../main.cpp" line="214"/>
        <source>Screen Brightness %1%</source>
        <translation>Brilho da Tela %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <source>Invalid file or URL: %1</source>
        <translation>Arquivo ou URL Inválidos: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="267"/>
        <source>Application entry is invalid: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="278"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>Está faltando a informação do lançamento do atalho do aplicativo  (atalho mal informado): 1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="291"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>Está faltando a URL do atalhos da URL: %1 </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="302"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>Está faltando o caminho para o diretório do atalho do diretório&quot; %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="307"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>Tipo de atalho desconhecido: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Binary Missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="421"/>
        <source>Application Error</source>
        <translation>Erro no Aplicativo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="421"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>O seguinte aplicativo encontrou um erro e teve que ser fechado:</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/core/lumina-open/i18n/lumina-open_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Abrir Com..</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Disponíveis</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Localização do Binário:</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Definir essa aplicação como padrão</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(Link de E-mail)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimédia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Educação</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Jogo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Ciência</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Utilitários</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="211"/>
        <source>[default] </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="278"/>
        <source>Find Application Binary</source>
        <translation>Encontrar binário da aplicação</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>File Error</source>
        <translation>Erro no Arquivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="191"/>
        <location filename="../main.cpp" line="197"/>
        <source>Audio Volume %1%</source>
        <translation>Volume do Som %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="205"/>
        <location filename="../main.cpp" line="214"/>
        <source>Screen Brightness %1%</source>
        <translation>Brilho da Tela %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <source>Invalid file or URL: %1</source>
        <translation>Arquivo ou URL Inválidos: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="267"/>
        <source>Application entry is invalid: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="278"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>Está faltando a informação do lançamento do atalho do aplicativo  (atalho mal informado): 1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="291"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>Está faltando a URL do atalhos da URL: %1 </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="302"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>Está faltando o caminho para o diretório do atalho do diretório&quot; %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="307"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>Tipo de atalho desconhecido: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="419"/>
        <source>Application Error</source>
        <translation>Erro no Aplicativo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="419"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>O seguinte aplicativo encontrou um erro e teve que ser fechado:</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished">Multimédia</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished">Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished">Educação</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished">Gráficos</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished">Rede</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished">Escritório</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished">Ciência</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished">Definições</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished">Sistema</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
